@@ -8,7 +8,9 @@ Pyro - Python Remote Objects.  Copyright by Irmen de Jong (irmen@razorvine.net).
 # PYRO_LOGLEVEL   (enable Pyro log config and set level)
 # PYRO_LOGFILE    (the name of the logfile if you don't like the default)
 
-import os, sys
+import os
+import sys
+import platform
 
 
 class Configuration(object):
@@ -18,7 +20,8 @@ class Configuration(object):
                "DETAILED_TRACEBACK", "SOCK_REUSE",
                "THREADPOOL_MINTHREADS", "THREADPOOL_MAXTHREADS",
                "THREADPOOL_IDLETIMEOUT", "HMAC_KEY", "AUTOPROXY",
-               "BROADCAST_ADDRS", "NATHOST", "NATPORT", "MAX_MESSAGE_SIZE")
+               "BROADCAST_ADDRS", "NATHOST", "NATPORT", "MAX_MESSAGE_SIZE",
+               "FLAME_ENABLED" )
 
     def __init__(self):
         self.reset()
@@ -51,6 +54,7 @@ class Configuration(object):
         self.AUTOPROXY = True
         self.MAX_MESSAGE_SIZE = 0   # 0 = unlimited
         self.BROADCAST_ADDRS = "<broadcast>, 0.0.0.0"   # comma separated list of broadcast addresses
+        self.FLAME_ENABLED = False
 
         if useenvironment:
             # process enviroment variables
@@ -101,11 +105,16 @@ class Configuration(object):
         # easy config diagnostics
         from Pyro4.constants import VERSION
         import inspect
+        if hasattr(platform, "python_implementation"):
+            implementation = platform.python_implementation()
+        else:
+            implementation = "Jython" if os.name=="java" else "???"
         config=self.asDict()
         config["LOGFILE"]=os.environ.get("PYRO_LOGFILE")
         config["LOGLEVEL"]=os.environ.get("PYRO_LOGLEVEL")
         result= ["Pyro version: %s" % VERSION,
                  "Loaded from: %s" % os.path.abspath(os.path.split(inspect.getfile(Configuration))[0]),
+                 "Python version: %s %s (%s, %s)" % (implementation, platform.python_version(), platform.system(), os.name),
                  "Active configuration settings:"]
         for n, v in sorted(config.items()):
             result.append("%s = %s" % (n, v))
