@@ -8,7 +8,6 @@ from __future__ import with_statement
 import re, struct, sys, time, os
 import logging, uuid
 import hashlib, hmac
-import functools
 try:
     import copyreg
 except ImportError:
@@ -16,9 +15,10 @@ except ImportError:
 from Pyro4 import constants, threadutil, util, socketutil, errors
 from Pyro4.socketserver.threadpoolserver import SocketServer_Threadpool
 from Pyro4.socketserver.multiplexserver import SocketServer_Select, SocketServer_Poll
+from Pyro4 import futures
 import Pyro4
 
-__all__=["URI", "Proxy", "Daemon", "callback", "batch", "async", "Future"]
+__all__=["URI", "Proxy", "Daemon", "callback", "batch", "async"]
 
 if sys.version_info>=(3,0):
     basestring=str
@@ -290,7 +290,7 @@ class Proxy(object):
                     data=self._pyroSerializer.deserialize(data, compressed=flags & MessageFactory.FLAGS_COMPRESSED)
                     if flags & MessageFactory.FLAGS_EXCEPTION:
                         if sys.platform=="cli":
-                            fixIronPythonExceptionForPickle(data, False)
+                            util.fixIronPythonExceptionForPickle(data, False)
                         raise data
                     else:
                         return data
@@ -433,7 +433,7 @@ class _BatchProxyAdapter(object):
 
     def __resultsgenerator(self, results):
         for result in results:
-            if isinstance(result, _ExceptionWrapper):
+            if isinstance(result, futures._ExceptionWrapper):
                 result.raiseIt()   # re-raise the remote exception locally.
             else:
                 yield result   # it is a regular result object, yield that and continue.
@@ -474,7 +474,7 @@ class _AsyncRemoteMethod(object):
         return _AsyncRemoteMethod(self.__proxy, "%s.%s" % (self.__name, name))
 
     def __call__(self, *args, **kwargs):
-        result=FutureResult()
+        result=futures.FutureResult()
         thread=threadutil.Thread(target=self.__asynccall, args=(result, args, kwargs))
         thread.setDaemon(True)
         thread.start()
@@ -489,130 +489,7 @@ class _AsyncRemoteMethod(object):
             asyncresult.value=value
         except Exception:
             # ignore any exceptions here, return them as part of the async result instead
-            asyncresult.value=_ExceptionWrapper(sys.exc_info()[1])
-
-
-class FutureResult(object):
-    """
-    The result object for asynchronous calls.
-    """
-    def __init__(self):
-        self.__ready=threadutil.Event()
-        self.callchain=[]
-        self.valueLock=threadutil.Lock()
-
-    def wait(self, timeout=None):
-        """
-        Wait for the result to become available, with optional timeout (in seconds).
-        Returns True if the result is ready, or False if it still isn't ready.
-        """
-        result=self.__ready.wait(timeout)
-        if result is None:
-            # older pythons return None from wait()
-            return self.__ready.isSet()
-        return result
-
-    @property
-    def ready(self):
-        """Boolean that contains the readiness of the async result"""
-        return self.__ready.isSet()
-
-    def get_value(self):
-        self.__ready.wait()
-        if isinstance(self.__value, _ExceptionWrapper):
-            self.__value.raiseIt()
-        else:
-            return self.__value
-
-    def set_value(self, value):
-        with self.valueLock:
-            self.__value=value
-            # walk the call chain but only as long as the result is not an exception
-            if not isinstance(value, _ExceptionWrapper):
-                for call, args, kwargs in self.callchain:
-                    call = functools.partial(call, self.__value)
-                    self.__value = call(*args, **kwargs)
-                    if isinstance(self.__value, _ExceptionWrapper):
-                        break
-            self.callchain=[]
-            self.__ready.set()
-
-    value=property(get_value, set_value, None, "The result value of the call. Reading it will block if not available yet.")
-
-    def then(self, call, *args, **kwargs):
-        """
-        Add a callable to the call chain, to be invoked when the results become available.
-        The result of the current call will be used as the first argument for the next call.
-        Optional extra arguments can be provided in args and kwargs.
-        """
-        if self.__ready.isSet():
-            # value is already known, we need to process it immediately (can't use the callchain anymore)
-            call = functools.partial(call, self.__value)
-            self.__value = call(*args, **kwargs)
-        else:
-            # add the call to the callchain, it will be processed later when the result arrives
-            with self.valueLock:
-                self.callchain.append((call, args, kwargs))
-        return self
-
-
-class Future(object):
-    """
-    Holds a callable that will be executed asynchronously and provide its
-    result value some time in the future.
-    This is a more general implementation than the AsyncRemoteMethod, which
-    only works with Pyro proxies (and provides a bit different syntax).
-    """
-    def __init__(self, callable):
-        self.callable = callable
-        self.chain = []
-
-    def __call__(self, *args, **kwargs):
-        """
-        Start the future call with the provided arguments.
-        Control flow returns immediately, with a FutureResult object.
-        """
-        chain = self.chain
-        del self.chain  # make it impossible to add new calls to the chain once we started executing it
-        result=FutureResult()  # notice that the call chain doesn't sit on the result object
-        thread=threadutil.Thread(target=self.__asynccall, args=(result, chain, args, kwargs))
-        thread.setDaemon(True)
-        thread.start()
-        return result
-
-    def __asynccall(self, asyncresult, chain, args, kwargs):
-        try:
-            value = self.callable(*args, **kwargs)
-            # now walk the callchain, passing on the previous value as first argument
-            for call, args, kwargs in chain:
-                call = functools.partial(call, value)
-                value = call(*args, **kwargs)
-            asyncresult.value = value
-        except Exception:
-            # ignore any exceptions here, return them as part of the async result instead
-            asyncresult.value=_ExceptionWrapper(sys.exc_info()[1])
-
-    def then(self, call, *args, **kwargs):
-        """
-        Add a callable to the call chain, to be invoked when the results become available.
-        The result of the current call will be used as the first argument for the next call.
-        Optional extra arguments can be provided in args and kwargs.
-        """
-        self.chain.append((call, args, kwargs))
-
-
-class _ExceptionWrapper(object):
-    """Class that wraps a remote exception. If this is returned, Pyro will
-    re-throw the exception on the receiving side. Usually this is taken care of
-    by a special response message flag, but in the case of batched calls this
-    flag is useless and another mechanism was needed."""
-    def __init__(self, exception):
-        self.exception=exception
-
-    def raiseIt(self):
-        if sys.platform=="cli":
-            fixIronPythonExceptionForPickle(self.exception, False)
-        raise self.exception
+            asyncresult.value=futures._ExceptionWrapper(sys.exc_info()[1])
 
 
 def batch(proxy):
@@ -902,8 +779,8 @@ class Daemon(object):
                             log.debug("Exception occurred while handling batched request: %s", xv)
                             xv._pyroTraceback=util.formatTraceback(detailed=Pyro4.config.DETAILED_TRACEBACK)
                             if sys.platform=="cli":
-                                fixIronPythonExceptionForPickle(xv, True)  # piggyback attributes
-                            data.append(_ExceptionWrapper(xv))
+                                util.fixIronPythonExceptionForPickle(xv, True)  # piggyback attributes
+                            data.append(futures._ExceptionWrapper(xv))
                             break   # stop processing the rest of the batch
                         else:
                             data.append(result)
@@ -949,8 +826,18 @@ class Daemon(object):
         """send an exception back including the local traceback info"""
         exc_value._pyroTraceback=tbinfo
         if sys.platform=="cli":
-            fixIronPythonExceptionForPickle(exc_value, True)  # piggyback attributes
-        data, _=self.serializer.serialize(exc_value)
+            util.fixIronPythonExceptionForPickle(exc_value, True)  # piggyback attributes
+        try:
+            data, _=self.serializer.serialize(exc_value)
+        except:
+            # the exception object couldn't be serialized, use a generic PyroError instead
+            xt, xv, tb = sys.exc_info()
+            msg = "Error serializing exception: %s. Original exception: %s: %s" % (str(xv), type(exc_value), str(exc_value))
+            exc_value = errors.PyroError(msg)
+            exc_value._pyroTraceback=tbinfo
+            if sys.platform=="cli":
+                util.fixIronPythonExceptionForPickle(exc_value, True)  # piggyback attributes
+            data, _=self.serializer.serialize(exc_value)
         msg=MessageFactory.createMessage(MessageFactory.MSG_RESULT, data, MessageFactory.FLAGS_EXCEPTION, seq)
         del data
         connection.send(msg)
@@ -1053,28 +940,6 @@ class Daemon(object):
         return {}   # a little hack to make it possible to serialize Pyro objects.
 
 
-class __IronPythonExceptionArgs(object):
-    def __init__(self,data):
-        self.data=data
-
-
-def fixIronPythonExceptionForPickle(exceptionObject, addAttributes):
-    """function to hack around a bug in IronPython where it doesn't pickle
-    exception attributes. We piggyback them into the exception's args."""
-    if hasattr(exceptionObject, "args"):
-        if addAttributes:
-            # piggyback the attributes on the exception args instead.
-            exceptionObject.args+=(__IronPythonExceptionArgs(vars(exceptionObject)),)
-        else:
-            # check if there is a piggybacked object in the args
-            # if there is, extract the exception attributes from it.
-            if len(exceptionObject.args) > 0:
-                piggyback = exceptionObject.args[-1]
-                if isinstance(piggyback, __IronPythonExceptionArgs):
-                    exceptionObject.args = exceptionObject.args[:-1]
-                    exceptionObject.__dict__.update(piggyback.data)
-
-
 # decorators
 
 def callback(object):
@@ -1085,3 +950,6 @@ def callback(object):
     """
     object._pyroCallback=True
     return object
+
+
+# backward compatibility
